@@ -2,7 +2,6 @@
     use strict;
     use warnings;
     use POSIX;
-    use Config;
     use Math::MPFR::Prec;
     use Math::MPFR::Random;
 
@@ -151,7 +150,7 @@ Rmpfr_set_prec_raw Rmpfr_set_q Rmpfr_set_si Rmpfr_set_si_2exp Rmpfr_set_sj
 Rmpfr_set_sj_2exp Rmpfr_set_str Rmpfr_set_ui Rmpfr_set_ui_2exp
 Rmpfr_set_uj Rmpfr_set_uj_2exp
 Rmpfr_set_DECIMAL64 Rmpfr_get_DECIMAL64 Rmpfr_set_float128 Rmpfr_get_float128
-Rmpfr_set_FLOAT128 Rmpfr_get_FLOAT128 Rmpfr_set_DECIMAL128 Rmpfr_get_DECIMAL128
+Rmpfr_set_FLOAT128 Rmpfr_get_FLOAT128
 Rmpfr_set_underflow Rmpfr_set_z Rmpfr_sgn Rmpfr_si_div Rmpfr_si_sub Rmpfr_sin
 Rmpfr_sin_cos Rmpfr_sinh_cosh
 Rmpfr_sinh Rmpfr_sqr Rmpfr_sqrt Rmpfr_sqrt_ui Rmpfr_strtofr Rmpfr_sub
@@ -177,10 +176,9 @@ Rmpfr_fmodquo Rmpfr_fpif_export Rmpfr_fpif_import Rmpfr_flags_clear Rmpfr_flags_
 Rmpfr_flags_test Rmpfr_flags_save Rmpfr_flags_restore Rmpfr_rint_roundeven Rmpfr_roundeven
 Rmpfr_nrandom Rmpfr_erandom Rmpfr_fmma Rmpfr_fmms Rmpfr_log_ui Rmpfr_gamma_inc Rmpfr_beta
 Rmpfr_round_nearest_away rndna
-atonv nvtoa atodouble Rmpfr_dot Rmpfr_get_str_ndigits
 );
 
-    our $VERSION = '4.09_001';
+    our $VERSION = '4.01';
     #$VERSION = eval $VERSION;
 
     DynaLoader::bootstrap Math::MPFR $VERSION;
@@ -256,7 +254,7 @@ Rmpfr_set_prec_raw Rmpfr_set_q Rmpfr_set_si Rmpfr_set_si_2exp Rmpfr_set_sj
 Rmpfr_set_sj_2exp Rmpfr_set_str Rmpfr_set_ui Rmpfr_set_ui_2exp
 Rmpfr_set_uj Rmpfr_set_uj_2exp
 Rmpfr_set_DECIMAL64 Rmpfr_get_DECIMAL64 Rmpfr_set_float128 Rmpfr_get_float128
-Rmpfr_set_FLOAT128 Rmpfr_get_FLOAT128 Rmpfr_set_DECIMAL128 Rmpfr_get_DECIMAL128
+Rmpfr_set_FLOAT128 Rmpfr_get_FLOAT128
 Rmpfr_set_underflow Rmpfr_set_z Rmpfr_sgn Rmpfr_si_div Rmpfr_si_sub Rmpfr_sin
 Rmpfr_sin_cos Rmpfr_sinh_cosh
 Rmpfr_sinh Rmpfr_sqr Rmpfr_sqrt Rmpfr_sqrt_ui Rmpfr_strtofr Rmpfr_sub
@@ -282,18 +280,14 @@ Rmpfr_fmodquo Rmpfr_fpif_export Rmpfr_fpif_import Rmpfr_flags_clear Rmpfr_flags_
 Rmpfr_flags_test Rmpfr_flags_save Rmpfr_flags_restore Rmpfr_rint_roundeven Rmpfr_roundeven
 Rmpfr_nrandom Rmpfr_erandom Rmpfr_fmma Rmpfr_fmms Rmpfr_log_ui Rmpfr_gamma_inc Rmpfr_beta
 Rmpfr_round_nearest_away rndna
-atonv nvtoa atodouble Rmpfr_dot Rmpfr_get_str_ndigits
 )]);
 
-
 $Math::MPFR::NNW = 0; # Set to 1 to allow "non-numeric" warnings for operations involving
                       # strings that contain non-numeric characters.
 
 $Math::MPFR::NOK_POK = 0; # Set to 1 to allow warnings in new() and overloaded operations when
                           # a scalar that has set both NOK (NV) and POK (PV) flags is encountered
 
-%Math::MPFR::NV_properties = _get_NV_properties();
-
 sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
 
 sub Rmpfr_out_str {
@@ -734,67 +728,6 @@ sub Rmpfr_round_nearest_away {
   return $ret;
 }
 
-sub _get_NV_properties {
-
-  my($bits, $PREC, $max_dig, $min_pow, $normal_min, $NV_MAX, $nvtype, $emax, $emin);
-
-  if   ($Config{nvtype} eq 'double')     {
-    $bits = 53;  $PREC = 64;  $max_dig = 17; $min_pow = -1074;
-    $normal_min = 2 ** -1022; $NV_MAX = POSIX::DBL_MAX; $emin = -1073; $emax = 1024;
-  }
-
-  elsif($Config{nvtype} eq '__float128') {
-    $bits = 113; $PREC = 128; $max_dig = 36; $min_pow = -16494; $normal_min = 2 ** -16382;
-    $NV_MAX = 1.18973149535723176508575932662800702e+4932; $emin = -16493; $emax = 16384;
-  }
-
-  elsif($Config{nvtype} eq 'long double') {
-
-    if(_required_ldbl_mant_dig() == 53)      {
-      $bits = 53;  $PREC = 64;  $max_dig = 17; $min_pow = -1074;
-      $normal_min = 2 ** -1022; $NV_MAX = POSIX::DBL_MAX; $emin = -1073; $emax = 1024;
-    }
-
-    elsif(_required_ldbl_mant_dig() == 113)  {
-      $bits = 113; $PREC = 128; $max_dig = 36; $min_pow = -16494;
-      $normal_min = 2 ** -16382; $NV_MAX = POSIX::LDBL_MAX; $emin = -16493; $emax = 16384;
-    }
-
-    elsif(_required_ldbl_mant_dig() == 64)   {
-      $bits = 64;  $PREC = 80;  $max_dig = 21; $min_pow = -16445;
-      $normal_min = 2 ** -16382; $NV_MAX = POSIX::LDBL_MAX; $emin = -16444; $emax = 16384;
-    }
-
-    elsif(_required_ldbl_mant_dig() == 2098) {
-      $bits = 2098;  $PREC = 2104;  $max_dig = 33; $min_pow = -1074;
-      $normal_min = 2 ** -1022; $NV_MAX = POSIX::LDBL_MAX; $emin = -1073; $emax = 1024;
-    }
-
-    else {
-      my %properties = ('type' => 'unknown long double type');
-      return %properties;
-    }
-  }
-  else {
-      my %properties = ('type' => 'unknown nv type');
-      return %properties;
-  }
-
-  my %properties = (
-    'bits'       => $bits,
-    'PREC'       => $PREC,
-    'max_dig'    => $max_dig,
-    'min_pow'    => $min_pow,
-    'normal_min' => $normal_min,
-    'NV_MAX'     => $NV_MAX,
-    'emin'       => $emin,
-    'emax'       => $emax,
-                   );
-
-  return %properties;
-}
-
-
 *Rmpfr_get_z_exp             = \&Rmpfr_get_z_2exp;
 *prec_cast                   = \&Math::MPFR::Prec::prec_cast;
 *Rmpfr_randinit_default      = \&Math::MPFR::Random::Rmpfr_randinit_default;
